# $Id: /local/CPAN/Handel/t/lib/Handel/Subclassing/Storage.pm 1043 2007-06-24T15:35:46.298350Z claco  $
package Handel::Subclassing::Storage;
use strict;
use warnings;
use base qw/Handel::Storage/;

1;
